======================
Dialectal Arabic Tools
======================



.. image:: https://pyup.io/repos/github/disooqi/dialectal_arabic_tools/shield.svg
     :target: https://pyup.io/repos/github/disooqi/dialectal_arabic_tools/
     :alt: Updates


Dialectal Arabic Tools comprises the different modules developed in Qatar Computing Research Institute (QCRI) developed by the ALT team to handle Dialectal Arabic Segmentation, POS tagging, daicrtization and more



Features
--------

* TODO

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

